require("scripts.string")

---@type [string]
local IgnoredResourceIDs = settings.startup["ignored-resources"].value:gsub("%s+", ""):split(",")

---@type [string]
local InfiniteOilResources = settings.startup["infinite-oil-resources"].value:gsub("%s+", ""):split(",")

---@type [string]
local InfiniteOreResources = settings.startup["infinite-ore-resources"].value:gsub("%s+", ""):split(",")

---@type [string]
local UnconfiguredResources = {}

local configureResource = function (name, resource)
  if IgnoredResourceIDs[name] then
    return
  end

  if InfiniteOreResources[name] then
    return
  end

  resource.infinite = true
  resource.infinite_depletion_amount = 0
  resource.minable.result = name

  if not resource.minimum or resource.minimum < 100 then resource.minimum = 100 end
  if not resource.normal or resource.normal < resource.minimum then resource.normal = resource.minimum end

  if not InfiniteOilResources[name] then
    table.insert(UnconfiguredResources, name)
  end
end

for k, v in pairs(data.raw.resource) do
  configureResource(k, v)
end

log("IgnoredResourceIDs: (" ..table_size(IgnoredResourceIDs).. " items)" ..serpent.block(IgnoredResourceIDs))
log("InfiniteOilResources: (" ..table_size(InfiniteOilResources).. " items)" ..serpent.block(InfiniteOilResources))
log("InfiniteOreResources (" ..table_size(InfiniteOreResources).. " items): " ..serpent.block(InfiniteOreResources))
log("UnconfiguredResources (" ..table_size(UnconfiguredResources).. " items): " ..serpent.block(UnconfiguredResources))